/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/*******************************************************************************
 *  MSP432 I2C - EUSCI_B0_BASE I2C Master TX multiple bytes to MSP432 Slave
 *
 *  Description: This demo connects two MSP432 's via the I2C bus. The master
 *  transmits to the slave. This is the MASTER CODE. It continuously
 *  transmits an array of data and demonstrates how to implement an I2C
 *  master transmitter sending multiple bytes using the USCI_B0 TX interrupt.
 *  ACLK = n/a, MCLK = HSMCLK = SMCLK = BRCLK = default DCO = ~3.0MHz
 *
 *                                /|\  /|\
 *                MSP432P401      10k  10k      MSP432P401
 *                   slave         |    |         master
 *             -----------------   |    |   -----------------
 *            |     P1.6/UCB0SDA|<-|----+->|P1.6/UCB0SDA     |
 *            |                 |  |       |                 |
 *            |                 |  |       |                 |
 *            |     P1.7/UCB0SCL|<-+------>|P1.7/UCB0SCL     |
 *            |                 |          |                 |
 *
 ******************************************************************************/
/* DriverLib Includes */
#include <ti/devices/msp432p4xx/driverlib/driverlib.h>

/* Standard Includes */
#include <stdint.h>
#include <stdbool.h>

/* Slave Address for I2C Slave */
#define SLAVE_ADDRESS1 0x40
#define SLAVE_ADDRESS2 0x33
#define SLAVE_ADDRESS3 0x34
#define SLAVE_ADDRESS4 0x35
/* Statics */
const eUSCI_I2C_MasterConfig i2cConfig =
{
        EUSCI_B_I2C_CLOCKSOURCE_SMCLK,          // SMCLK Clock Source
        3000000,                                // SMCLK = 3MHz
        EUSCI_B_I2C_SET_DATA_RATE_400KBPS,      // Desired I2C Clock of 400khz
        0,                                      // No byte counter threshold
        EUSCI_B_I2C_NO_AUTO_STOP                // No Autostop
};
unsigned char table[]={
               0x00,0x40,
               0x07,0x08,
               0x08,0x08,
               0x09,0x08,
               0x0a,0x08,
               0x0b,0x08,
               0x0c,0x08,
               0x0d,0x08,
               0x0e,0x08,
               0x0f,0x08,
               0x22,0x50,
               0x23,0x50,
               0x24,0x50,
               0x25,0x50,
               0x26,0x50,
               0x27,0x50,
               0x28,0x50,
               0x29,0x50,
               0x2a,0x50,
               0x2f,0x28,
               0x16,0xef,
               0x17,0xef,
               0x18,0xef,
               0x19,0xef,
               0x1a,0xef,
               0x1b,0xef,
               0x1c,0xef,
               0x1d,0xef,
               0x1e,0xef
};
unsigned char exp[]={0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08};
unsigned char current[]={0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50};
unsigned char pwm[]={0xef,0xef,0xef,0xef,0xef,0xef,0xef,0xef,0xef};
unsigned char pwm_0[]={0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
unsigned char table_32[]={
0x00,0x49,0x00,0x92,0x01,0x24,0x00,0xDB,0x01,0xB6,0x01,0x6D,0x01,0xFF,0x00,0x49,
0x00,0x92,0x9C,0x00,0x9C,0x86,0x28,0xC8,0x21,0xFF,0x74,0x00,0x28,0xC8,0x21,0xFF,
0x74,0x00,0x9D,0x80,0xA3,0x02,0x9F,0x87,0x1E,0xC8,0x74,0x00,0x74,0x00,0x9F,0x88,
0x3E,0xC8,0x31,0xFF,0x3E,0xC8,0x31,0xFF,0x9F,0x87,0x19,0xFF,0x74,0x00,0x90,0x4B,
0x9D,0x07,0x84,0x60,0x9D,0x04,0x92,0x14,0x84,0x60,0x9D,0x01,0x92,0x14,0x84,0x60,
0x91,0x14,0x44,0x00,0xBF,0x97,0xA1,0x97,0x4C,0x00,0x9F,0x86,0x40,0x00,0x74,0x00,
0x90,0x4B,0x9F,0x87,0x14,0xC8,0x74,0x00,0x9D,0x08,0x84,0x60,0x9D,0x05,0x92,0x14,
0x84,0x60,0x9D,0x02,0x92,0x14,0x84,0x60,0x91,0x14,0x44,0x00,0xBF,0xAB,0xA1,0xAB,
0x4C,0x00,0x9F,0x86,0x40,0x00,0x9F,0x87,0x14,0xC8,0x46,0x00,0x9D,0x02,0x40,0xC8,
0x46,0x00,0x9D,0x05,0x40,0xC8,0x46,0x00,0x9D,0x08,0x40,0xC8,0x46,0x00,0x9D,0x02,
0x40,0x00,0x46,0x00,0x9D,0x05,0x40,0x00,0x46,0x00,0x9D,0x08,0x40,0x00,0x46,0x00,
0xA3,0x4E,0xA8,0x3D,0x9F,0x86,0x40,0x00,0x46,0x00,0xA4,0x53,0x74,0x00,0x9D,0x01,
0x40,0xC8,0x46,0x00,0x9D,0x04,0x40,0xC8,0x46,0x00,0x9D,0x07,0x40,0xC8,0x46,0x00,
0xA3,0x5E,0x74,0x00,0x9D,0x07,0x40,0x00,0x46,0x00,0x9D,0x04,0x40,0x00,0x46,0x00,
0x9D,0x01,0x40,0x00,0x46,0x00,0xA2,0x55,0x9D,0x00,0xE0,0x04,0xE2,0x00,0x00,0x00,
0xE0,0x80,0x9F,0x87,0x14,0xC8,0x4A,0x00,0x9D,0x02,0x40,0xC8,0x4A,0x00,0x9D,0x05,
0x40,0xC8,0x4A,0x00,0x9D,0x08,0x40,0xC8,0x4A,0x00,0x9D,0x02,0x40,0x00,0x4A,0x00,
0x9D,0x05,0x40,0x00,0x4A,0x00,0x9D,0x08,0x40,0x00,0x4A,0x00,0x9D,0x03,0x40,0xC8,
0x4A,0x00,0x9D,0x06,0x40,0xC8,0x4A,0x00,0x9D,0x09,0x40,0xC8,0x4A,0x00,0x9D,0x03,
0x40,0x00,0x4A,0x00,0x9D,0x06,0x40,0x00,0x4A,0x00,0x9D,0x09,0x40,0x00,0x4A,0x00,
0xA5,0x04,0x9F,0x86,0x40,0x00,0x4A,0x00,0xA1,0x2B,0x9D,0x00,0xE0,0x08,0x00,0x00,
0xE1,0x00,0x9D,0x03,0x40,0x23,0x46,0x00,0x9D,0x06,0x40,0x37,0x46,0x00,0x9D,0x09,
0x40,0x4B,0x46,0x00,0xA9,0x09,0x9D,0x09,0x40,0x00,0x46,0x00,0x9D,0x06,0x40,0x00,
0x46,0x00,0x9D,0x03,0x40,0x00,0x46,0x00,0xA2,0x01,0x9D,0x00,0xE0,0x02,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

unsigned char table_33[]={
0x00,0x49,0x00,0x92,0x01,0x24,0x00,0xDB,0x01,0xB6,0x01,0x6D,0x01,0xFF,0x00,0x49,
0x00,0x92,0x9C,0x00,0x9C,0x86,0x28,0xC8,0x21,0xFF,0x74,0x00,0x28,0xC8,0x21,0xFF,
0x74,0x00,0x9D,0x80,0xA3,0x02,0x9F,0x87,0x1E,0xC8,0x74,0x00,0x74,0x00,0x9F,0x88,
0x3E,0xC8,0x31,0xFF,0x3E,0xC8,0x31,0xFF,0x9F,0x87,0x19,0xFF,0x74,0x00,0x90,0x87,
0x9D,0x07,0x84,0x60,0x9D,0x04,0x92,0x14,0x84,0x60,0x9D,0x01,0x92,0x14,0x84,0x60,
0x91,0x14,0x44,0x00,0xBF,0x97,0xA1,0x97,0x4C,0x00,0x9F,0x86,0x40,0x00,0x74,0x00,
0x90,0x87,0x9F,0x87,0x14,0xC8,0x74,0x00,0x9D,0x08,0x84,0x60,0x9D,0x05,0x92,0x14,
0x84,0x60,0x9D,0x02,0x92,0x14,0x84,0x60,0x91,0x14,0x44,0x00,0xBF,0xAB,0xA1,0xAB,
0x4C,0x00,0x9F,0x86,0x40,0x00,0x9F,0x87,0x14,0xC8,0x46,0x00,0xA1,0xBC,0x9D,0x02,
0x40,0xC8,0x46,0x00,0x9D,0x05,0x40,0xC8,0x46,0x00,0x9D,0x08,0x40,0xC8,0x46,0x00,
0x9D,0x02,0x40,0x00,0x46,0x00,0x9D,0x05,0x40,0x00,0x46,0x00,0x9D,0x08,0x40,0x00,
0x46,0x00,0xA3,0x4F,0xA8,0x3E,0x9F,0x86,0x40,0x00,0x46,0x00,0xA2,0xD4,0x74,0x00,
0x46,0x00,0xA1,0x57,0x9D,0x01,0x40,0xC8,0x46,0x00,0x9D,0x04,0x40,0xC8,0x46,0x00,
0x9D,0x07,0x40,0xC8,0x46,0x00,0x74,0x00,0x9D,0x07,0x40,0x00,0x46,0x00,0x9D,0x04,
0x40,0x00,0x46,0x00,0x9D,0x01,0x40,0x00,0x46,0x00,0xA1,0xEB,0xA2,0x56,0x9D,0x00,
0xE0,0x04,0xE2,0x00,0x00,0x00,0xE0,0x80,0x9F,0x87,0x14,0xC8,0x4A,0x00,0xA1,0x83,
0x9D,0x02,0x40,0xC8,0x4A,0x00,0x9D,0x05,0x40,0xC8,0x4A,0x00,0x9D,0x08,0x40,0xC8,
0x4A,0x00,0x9D,0x02,0x40,0x00,0x4A,0x00,0x9D,0x05,0x40,0x00,0x4A,0x00,0x9D,0x08,
0x40,0x00,0x4A,0x00,0x9D,0x03,0x40,0xC8,0x4A,0x00,0x9D,0x06,0x40,0xC8,0x4A,0x00,
0x9D,0x09,0x40,0xC8,0x4A,0x00,0x9D,0x03,0x40,0x00,0x4A,0x00,0x9D,0x06,0x40,0x00,
0x4A,0x00,0x9D,0x09,0x40,0x00,0x4A,0x00,0xA5,0x05,0x9F,0x86,0x40,0x00,0x9D,0x00,
0xE0,0x08,0x00,0x00,0xE1,0x00,0x46,0x00,0xA1,0x01,0x9D,0x03,0x40,0x5F,0x46,0x00,
0x9D,0x06,0x40,0x73,0x46,0x00,0x9D,0x09,0x40,0x87,0x46,0x00,0xA6,0x0B,0x9D,0x09,
0x40,0x00,0x46,0x00,0x9D,0x06,0x40,0x00,0x46,0x00,0x9D,0x03,0x40,0x00,0x46,0x00,
0xA1,0x95,0xA2,0x01,0x9D,0x00,0xE0,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

unsigned char table_34[]={
0x00,0x49,0x00,0x92,0x01,0x24,0x00,0xDB,0x01,0xB6,0x01,0x6D,0x01,0xFF,0x00,0x49,
0x00,0x92,0x9C,0x00,0x9C,0x86,0x28,0xC8,0x21,0xFF,0x74,0x00,0x28,0xC8,0x21,0xFF,
0x74,0x00,0x9D,0x80,0xA3,0x02,0x9F,0x87,0x1E,0xC8,0x74,0x00,0x74,0x00,0x9F,0x88,
0x3E,0xC8,0x31,0xFF,0x3E,0xC8,0x31,0xFF,0x9F,0x87,0x19,0xFF,0x74,0x00,0x90,0xC3,
0x9D,0x07,0x84,0x60,0x9D,0x04,0x92,0x14,0x84,0x60,0x9D,0x01,0x92,0x14,0x84,0x60,
0x91,0x14,0x44,0x00,0xBF,0x97,0xA1,0x97,0x4C,0x00,0x9F,0x86,0x40,0x00,0x74,0x00,
0x90,0xC3,0x9F,0x87,0x14,0xC8,0x74,0x00,0x9D,0x08,0x84,0x60,0x9D,0x05,0x92,0x14,
0x84,0x60,0x9D,0x02,0x92,0x14,0x84,0x60,0x91,0x14,0x44,0x00,0xBF,0xAB,0xA1,0xAB,
0x4C,0x00,0x9F,0x86,0x40,0x00,0x9F,0x87,0x14,0xC8,0x46,0x00,0xA3,0x3C,0x9D,0x02,
0x40,0xC8,0x46,0x00,0x9D,0x05,0x40,0xC8,0x46,0x00,0x9D,0x08,0x40,0xC8,0x46,0x00,
0x9D,0x02,0x40,0x00,0x46,0x00,0x9D,0x05,0x40,0x00,0x46,0x00,0x9D,0x08,0x40,0x00,
0x46,0x00,0xA3,0x4F,0xA8,0x3E,0x9F,0x86,0x40,0x00,0x46,0x00,0xA1,0x54,0x74,0x00,
0x46,0x00,0xA1,0x57,0x9D,0x07,0x40,0xC8,0x46,0x00,0x9D,0x04,0x40,0xC8,0x46,0x00,
0x9D,0x01,0x40,0xC8,0x46,0x00,0x74,0x00,0x9D,0x01,0x40,0x00,0x46,0x00,0x9D,0x04,
0x40,0x00,0x46,0x00,0x9D,0x07,0x40,0x00,0x46,0x00,0xA1,0xEB,0xA2,0x56,0x9D,0x00,
0xE0,0x04,0xE2,0x00,0x00,0x00,0xE0,0x80,0x9F,0x87,0x14,0xC8,0x4A,0x00,0x9D,0x03,
0x40,0xC8,0x4A,0x00,0x9D,0x06,0x40,0xC8,0x4A,0x00,0x9D,0x09,0x40,0xC8,0x4A,0x00,
0x9D,0x03,0x40,0x00,0x4A,0x00,0x9D,0x06,0x40,0x00,0x4A,0x00,0x9D,0x09,0x40,0x00,
0x4A,0x00,0x9D,0x02,0x40,0xC8,0x4A,0x00,0x9D,0x05,0x40,0xC8,0x4A,0x00,0x9D,0x08,
0x40,0xC8,0x4A,0x00,0x9D,0x02,0x40,0x00,0x4A,0x00,0x9D,0x05,0x40,0x00,0x4A,0x00,
0x9D,0x08,0x40,0x00,0x4A,0x00,0xA5,0x04,0x9F,0x86,0x40,0x00,0x4A,0x00,0xA1,0x2B,
0x9D,0x00,0xE0,0x08,0x00,0x00,0xE1,0x00,0x46,0x00,0xA2,0x81,0x9D,0x03,0x40,0x9B,
0x46,0x00,0x9D,0x06,0x40,0xAF,0x46,0x00,0x9D,0x09,0x40,0xC3,0x46,0x00,0xA3,0x0B,
0x9D,0x09,0x40,0x00,0x46,0x00,0x9D,0x06,0x40,0x00,0x46,0x00,0x9D,0x03,0x40,0x00,
0x46,0x00,0xA3,0x15,0xA2,0x01,0x9D,0x00,0xE0,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

unsigned char table_35[]={
0x00,0x49,0x00,0x92,0x01,0x24,0x00,0xDB,0x01,0xB6,0x01,0x6D,0x01,0xFF,0x00,0x49,
0x00,0x92,0x9C,0x00,0x9C,0x86,0x28,0xC8,0x21,0xFF,0x74,0x00,0x28,0xC8,0x21,0xFF,
0x74,0x00,0x9D,0x80,0xA3,0x02,0x9F,0x87,0x1E,0xC8,0x74,0x00,0x74,0x00,0x9F,0x88,
0x3E,0xC8,0x31,0xFF,0x3E,0xC8,0x31,0xFF,0x9F,0x87,0x19,0xFF,0x74,0x00,0x90,0xFF,
0x9D,0x07,0x84,0x60,0x9D,0x04,0x92,0x14,0x84,0x60,0x9D,0x01,0x92,0x14,0x84,0x60,
0x91,0x14,0x44,0x00,0xBF,0x97,0xA1,0x97,0x4C,0x00,0x9F,0x86,0x40,0x00,0x74,0x00,
0x90,0xFF,0x9F,0x87,0x14,0xC8,0x74,0x00,0x9D,0x08,0x84,0x60,0x9D,0x05,0x92,0x14,
0x84,0x60,0x9D,0x02,0x92,0x14,0x84,0x60,0x91,0x14,0x44,0x00,0xBF,0xAB,0xA1,0xAB,
0x4C,0x00,0x9F,0x86,0x40,0x00,0x9F,0x87,0x14,0xC8,0x46,0x00,0xA4,0xBC,0x9D,0x02,
0x40,0xC8,0x46,0x00,0x9D,0x05,0x40,0xC8,0x46,0x00,0x9D,0x08,0x40,0xC8,0x46,0x00,
0x9D,0x02,0x40,0x00,0x46,0x00,0x9D,0x05,0x40,0x00,0x46,0x00,0x9D,0x08,0x40,0x00,
0x46,0x00,0xA3,0x4F,0xA8,0x3E,0x9F,0x86,0x40,0x00,0x74,0x00,0x9D,0x07,0x40,0xC8,
0x46,0x00,0x9D,0x04,0x40,0xC8,0x46,0x00,0x9D,0x01,0x40,0xC8,0x46,0x00,0xA3,0x5D,
0x74,0x00,0x9D,0x01,0x40,0x00,0x46,0x00,0x9D,0x04,0x40,0x00,0x46,0x00,0x9D,0x07,
0x40,0x00,0x46,0x00,0xA2,0x54,0x9D,0x00,0xE0,0x04,0xE2,0x00,0x00,0x00,0xE0,0x80,
0x9F,0x87,0x14,0xC8,0x4A,0x00,0xA1,0x83,0x9D,0x03,0x40,0xC8,0x4A,0x00,0x9D,0x06,
0x40,0xC8,0x4A,0x00,0x9D,0x09,0x40,0xC8,0x4A,0x00,0x9D,0x03,0x40,0x00,0x4A,0x00,
0x9D,0x06,0x40,0x00,0x4A,0x00,0x9D,0x09,0x40,0x00,0x4A,0x00,0x9D,0x02,0x40,0xC8,
0x4A,0x00,0x9D,0x05,0x40,0xC8,0x4A,0x00,0x9D,0x08,0x40,0xC8,0x4A,0x00,0x9D,0x02,
0x40,0x00,0x4A,0x00,0x9D,0x05,0x40,0x00,0x4A,0x00,0x9D,0x08,0x40,0x00,0x4A,0x00,
0xA5,0x05,0x9F,0x86,0x40,0x00,0x9D,0x00,0xE0,0x08,0x00,0x00,0xE1,0x00,0x46,0x00,
0xA4,0x01,0x9D,0x03,0x40,0xD7,0x46,0x00,0x9D,0x06,0x40,0xEB,0x46,0x00,0x9D,0x09,
0x40,0xFF,0x46,0x00,0x9D,0x09,0x40,0x00,0x46,0x00,0x9D,0x06,0x40,0x00,0x46,0x00,
0x9D,0x03,0x40,0x00,0x46,0x00,0xA4,0x94,0xA2,0x01,0x9D,0x00,0xE0,0x02,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};



void SendData(unsigned char Chip_ADD, unsigned char *temp,int size)
{
    int  i,j;
   // j=28;
    MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, Chip_ADD);
    MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x00);  //send register address
    MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x00); // send register data
    __delay_cycles(50000); //6/25M=240ns
    for(i=0;i<size;i++)
    {
        MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, temp[i*2]);  //send register address
        MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,temp[i*2+1]); // send register data
    }
}
void SendData_1(unsigned char Chip_ADD,unsigned char *pwm,unsigned char *exp,unsigned char *current)// unsigned char *pwm,unsigned char *exp,unsigned char *currenty
{    int i;
       MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, Chip_ADD);

       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x00);  //send register address
       MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x00); // send register data
       __delay_cycles(50000); //6/25M=240ns
       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x00);  //send register address
       MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x40); // send register data

       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x2f);  //send register address
       MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x48); // send register data

       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x07);  //send register address
       for(i=0;i<9;i++)
       {MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,exp[i]);} // send register data
      // MAP_I2C_masterSendMultiByteStop(EUSCI_B1_BASE);

       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x22);  //send register address
       for(i=0;i<9;i++)
          {MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,current[i]);} // send register data
      // MAP_I2C_masterSendMultiByteStop(EUSCI_B1_BASE);

     MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x16);  //send register address
       for(i=0;i<9;i++)
          {MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,pwm[i]);} // send register data
      // MAP_I2C_masterSendMultiByteStop(EUSCI_B1_BASE);

    }

void load_SRAM()
{
    int i,j;
    //int temp=0x50;
MAP_I2C_setSlaveAddress(EUSCI_B1_BASE,0x40);  //
   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x2F);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x48);  // send register data

   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x02);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x54); // send register data

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x32);

   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4b);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x09); // send register data

   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4c);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x78); // send register data

   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4d);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xa8); // send register data
   for(j=0;j<16;j++)
   {
       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4F);  //send register address
       MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,j); // send register data

       MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE,0x50);  //send register address
       for(i=0;i<32;i++)
           MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,table_32[i+j*32]); // send register data
   }

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x33);
      MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4b);  //send register address
      MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x09); // send register data

      MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4c);  //send register address
      MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x7b); // send register data

      MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4d);  //send register address
      MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xaa); // send register data
      for(j=0;j<16;j++)
      {
          MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4F);  //send register address
          MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,j); // send register data

          MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE,0x50);  //send register address
          for(i=0;i<32;i++)
              MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,table_33[i+j*32]); // send register data
      }

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x34);
            MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4b);  //send register address
            MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x09); // send register data

            MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4c);  //send register address
            MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x7b); // send register data

            MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4d);  //send register address
            MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xab); // send register data
            for(j=0;j<16;j++)
            {
                MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4F);  //send register address
                MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,j); // send register data

                MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE,0x50);  //send register address
                for(i=0;i<32;i++)
                    MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,table_34[i+j*32]); // send register data
            }

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x35);
             MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4b);  //send register address
             MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x09); // send register data

             MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4c);  //send register address
             MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x77); // send register data

             MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4d);  //send register address
             MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xa6); // send register data
             for(j=0;j<16;j++)
             {
                 MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x4F);  //send register address
                 MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,j); // send register data

                 MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE,0x50);  //send register address
                 for(i=0;i<32;i++)
                      MAP_I2C_masterSendMultiByteNext(EUSCI_B1_BASE,table_35[i+j*32]); // send register data;
             }

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x32);
             MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x2F);  //send register address
             MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x49);  // send register data

             MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x3d);  //send register address
             MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x08);  // send register data

MAP_I2C_setSlaveAddress(EUSCI_B1_BASE, 0x40);
   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x02);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0x00); // send register data
   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x02);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xa8); // send register data
   MAP_I2C_masterSendMultiByteStart(EUSCI_B1_BASE, 0x01);  //send register address
   MAP_I2C_masterSendMultiByteFinish(EUSCI_B1_BASE,0xa8); // send register data


}

//![Simple I2C Config]
/* I2C Master Configuration Parameter */
//![Simple I2C Config]
int main(void)
{
    volatile uint32_t ii;
     int size;
    /* Disabling the Watchdog */
    MAP_WDT_A_holdTimer();
    MAP_CS_initClockSignal(CS_ACLK,CS_LFXTCLK_SELECT, CS_CLOCK_DIVIDER_1);
   GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P4,GPIO_PIN2,GPIO_PRIMARY_MODULE_FUNCTION);
    /* Select Port 6 for I2C - Set Pin 4, 5 to input Primary Module Function,
     *   (UCB1SIMO/UCB1SDA, UCB1SOMI/UCB1SCL).     */
    MAP_GPIO_setAsPeripheralModuleFunctionInputPin(GPIO_PORT_P6,
            GPIO_PIN5|GPIO_PIN4, GPIO_PRIMARY_MODULE_FUNCTION);
    GPIO_setAsOutputPin(GPIO_PORT_P5, GPIO_PIN6);

    //![Simple I2C Example]
    /* Initializing I2C Master to SMCLK at 400kbs with no autostop */
    MAP_I2C_initMaster(EUSCI_B1_BASE, &i2cConfig);
    /* Set Master in transmit mode */
    MAP_I2C_setMode(EUSCI_B1_BASE, EUSCI_B_I2C_TRANSMIT_MODE);
    /* Enable I2C Module to start operations */
    MAP_I2C_enableModule(EUSCI_B1_BASE);
    GPIO_setOutputLowOnPin(GPIO_PORT_P5, GPIO_PIN6); //PWM PIN
    __delay_cycles(6); //6/25M=240ns
    GPIO_setOutputHighOnPin(GPIO_PORT_P5, GPIO_PIN6);
    size=sizeof(table)/sizeof(table[0]);
    size=size/2;

    SendData_1(0x40,pwm_0,exp,current);
    load_SRAM();
    //load_SRAM(0x40);
   // SendData(0x40,table,size);
    while (1)
    {
        /* Delay between Transmissions */
       // for (ii = 0; ii < 4000; ii++);
       /* Making sure the last transaction has been completely sent out */
        while (MAP_I2C_masterIsStopSent(EUSCI_B1_BASE) == EUSCI_B_I2C_SENDING_STOP);
    }
}

/*******************************************************************************
 * The USCIAB0TX_ISR is structured such that it can be used to transmit any
 * number of bytes by pre-loading TXByteCtr with the byte count. Also, TXData
 * points to the next byte to transmit.
 ******************************************************************************/
void EUSCIB2_IRQHandler(void)
{
    uint_fast16_t status;

    status = MAP_I2C_getEnabledInterruptStatus(EUSCI_B1_BASE);
    MAP_I2C_clearInterruptFlag(EUSCI_B1_BASE, status);

    if (status & EUSCI_B_I2C_NAK_INTERRUPT)
    {
        MAP_I2C_masterSendStart(EUSCI_B1_BASE);
    }

    //if (status & EUSCI_B_I2C_TRANSMIT_INTERRUPT0)
    //{
   // }
}
